@@ -1,4 +1,5 @@
 from PySide6.QtCore import Qt
+from PySide6.QtGui import QPixmap
 from PySide6.QtWidgets import (
     QDialog,
     QFileDialog,
@@ -23,6 +24,7 @@ class ScriptFileDlg(QFileDialog):
         """
 
         super(ScriptFileDlg, self).__init__(parent)
+
         self._setup()
 
     def _setup(self) -> None:
@@ -31,8 +33,8 @@ class ScriptFileDlg(QFileDialog):
         """
 
         self.setAcceptMode(QFileDialog.AcceptOpen)
-        self.setDefaultSuffix("py")
-        self.setNameFilters(("Python脚本文件 (*.py *.pyw)", "All (*)"))
+        self.setViewMode(QFileDialog.Detail)
+        self.setNameFilters(("Python脚本文件 (*.py *.pyw)", "所有文件 (*)"))
         self.setFileMode(QFileDialog.ExistingFiles)
         self.setLabelText(QFileDialog.FileName, "Python入口文件")
         self.setLabelText(QFileDialog.FileType, "Python文件")
@@ -51,6 +53,7 @@ class IconFileDlg(QFileDialog):
         """
 
         super(IconFileDlg, self).__init__(parent)
+
         self._setup()
 
     def _setup(self) -> None:
@@ -59,8 +62,8 @@ class IconFileDlg(QFileDialog):
         """
 
         self.setAcceptMode(QFileDialog.AcceptOpen)
-        self.setDefaultSuffix("ico")
-        self.setNameFilters(("图标文件 (*.ico *.icns)", "All (*)"))
+        self.setViewMode(QFileDialog.Detail)
+        self.setNameFilters(("图标文件 (*.ico *.icns)", "所有文件 (*)"))
         self.setFileMode(QFileDialog.ExistingFile)
         self.setLabelText(QFileDialog.FileName, "图标")
         self.setLabelText(QFileDialog.FileType, "图标文件")
@@ -68,7 +71,29 @@ class IconFileDlg(QFileDialog):
         self.setLabelText(QFileDialog.Reject, "取消")
 
 
-class AboutMessage(QMessageBox):
+class AddDataDlg(QFileDialog):
+    """
+    用于添加附加数据的对话框
+    """
+
+    def __init__(self, parent: QWidget = None) -> None:
+        """
+        :param parent: 父控件对象
+        """
+
+        super(AddDataDlg, self).__init__(parent)
+
+        self._setup()
+
+    def _setup(self) -> None:
+        """
+        配置添加数据对话框 \n
+        """
+
+        pass
+
+
+class AboutDlg(QMessageBox):
     """
     用于显示关于信息的对话框
     """
@@ -78,7 +103,8 @@ class AboutMessage(QMessageBox):
         :param parent: 父控件对象
         """
 
-        super(AboutMessage, self).__init__(parent)
+        super(AboutDlg, self).__init__(parent)
+
         self._about_text: str = ""
         self._setup()
 
@@ -87,10 +113,13 @@ class AboutMessage(QMessageBox):
         配置关于信息对话框 \n
         """
 
-        self.setWindowTitle("关于Py2exe-GUI")
+        self.setWindowTitle("关于")
         self.setStandardButtons(QMessageBox.Ok)
         self.setTextFormat(Qt.MarkdownText)
         self.setText(self.about_text)
+        self.setIconPixmap(
+            QPixmap("py2exe_gui/Resources/Icons/Py2exe-GUI_icon_72px.png")
+        )
 
     @property
     def about_text(self) -> str:
@@ -99,11 +128,14 @@ class AboutMessage(QMessageBox):
         :return: 关于信息
         """
 
-        self._about_text = (
-            "Py2exe-GUI 是一个[开源程序](https://github.com/muziing/Py2exe-GUI)。\n\n"
-            "旨在为 [PyInstaller](https://pyinstaller.org/) 提供简单易用的图形界面。\n\n"
-            "作者：[muzing](https://muzing.top/about)。"
-        )
+        try:
+            with open(
+                "py2exe_gui/Resources/About.md", "r", encoding="utf-8"
+            ) as about_file:
+                self._about_text = about_file.read()
+        except FileNotFoundError:
+            self._about_text = "无法打开关于文档，请尝试重新获取本程序。"
+
         return self._about_text
 
 
@@ -113,7 +145,12 @@ class SubProcessDlg(QDialog):
     """
 
     def __init__(self, parent: QWidget = None) -> None:
+        """
+        :param parent: 父控件对象
+        """
+
         super(SubProcessDlg, self).__init__(parent)
+
         self.info_label = QLabel(self)
         self.browser = QTextBrowser(self)
         self._setup()
@@ -157,7 +194,7 @@ if __name__ == "__main__":
     # window = ScriptFileDlg()
     # window = IconFileDlg()
     # window.fileSelected.connect(lambda f: print(f))  # type: ignore
-    # window = AboutMessage()
+    # window = AboutDlg()
     window = SubProcessDlg()
     window.open()
     sys.exit(app.exec())
